*MARIE BALLIF et al.
*Seasonal variations in tuberculosis diagnosis among HIV-positive individuals in Southern Africa: Analysis of cohort studies at antiretroviral treatment programmes
*BMJ Open 2018
*DOI:10.1136/bmjopen-2017-017405
*********************************************************************
*********************************************************************

*Initial commands
******************
clear all
set more off
*Install commands
ssc install ci2
net from http://www.stata.com
net cd users
net cd vwiggins
net install grc1leg

*Define directory
cd "C:\Users\ballif\switchdrive\IEDEA\Seasonality\BORIS archive\"
*Open dataset
use "datasets\Seasonality_dataset.dta", clear
*Open log file
log using "log\TBseasonality2018", replace

*********************************************************************
**** Flowchart
*********************************************************************
count
tab cohort

*********************************************************************
**** Patient characteristics
*********************************************************************
tabstat age_haart, statistics(p25 p50 p75) by(ptb) m
ranksum age_haart, by(ptb)
tab gender ptb, m row col chi
tabstat cd4a_bas, statistics(p25 p50 p75) by(ptb) m
ranksum cd4a_bas, by(ptb)
tab ptb if cd4a_bas==.
tab aids_bas ptb, m row col chi
tab cohort ptb, m row col chi

*********************************************************************
**** Average monthly diagnosis counts
*********************************************************************
*Open dataset
use "datasets\collapsed_dataset_allmonths_final.dta", clear

*Average monthly haart start counts 
bysort cohort: summ haart_nb_mean, detail
summ haart_nb_mean, detail
*Average monthly PTB diagnosis counts 
bysort cohort: summ ptb_nb_mean, detail
summ ptb_nb_mean, detail
*Average monthly Extrapulmonary PTB diagnosis counts
bysort cohort: summ xptb_nb_mean, detail
summ xptb_nb_mean, detail
*Average monthly KS diagnosis counts
bysort cohort: summ ks_nb_mean, detail
summ ks_nb_mean, detail

*********************************************************************
**** Correlation coefficients and CI
*********************************************************************
*Correlation between haart and PTB deviations
bysort cohort: pwcorr ptb_dev haart_dev, sig
*Confidence intervals for correlations
ci2 ptb_dev haart_dev, corr
ci2 ptb_dev haart_dev if cohort==1, corr
ci2 ptb_dev haart_dev if cohort==2, corr
ci2 ptb_dev haart_dev if cohort==3, corr
ci2 ptb_dev haart_dev if cohort==4, corr
ci2 ptb_dev haart_dev if cohort==5, corr

*Correlation between haart and EPTB deviations
bysort cohort: pwcorr xptb_dev haart_dev, sig
*Confidence intervals for correlations
ci2 xptb_dev haart_dev, corr
ci2 xptb_dev haart_dev if cohort==1, corr
ci2 xptb_dev haart_dev if cohort==2, corr
ci2 xptb_dev haart_dev if cohort==3, corr
ci2 xptb_dev haart_dev if cohort==4, corr
ci2 xptb_dev haart_dev if cohort==5, corr

*Correlation between haart and KS deviations
bysort cohort: pwcorr ks_dev haart_dev, sig
*Confidence intervals for correlations
ci2 ks_dev haart_dev, corr
ci2 ks_dev haart_dev if cohort==1, corr
ci2 ks_dev haart_dev if cohort==2, corr
ci2 ks_dev haart_dev if cohort==3, corr
ci2 ks_dev haart_dev if cohort==4, corr
ci2 ks_dev haart_dev if cohort==5, corr

*MONTHLY PERCENTS OF THE YEAR TOTALS
*************************************
bysort cohort: list cohort ptb_nb_mean ptb_mt_mean ptb_peak_mt ptb_peak_pt ptb_trough_mt ptb_trough_pt ptb_variablity if year==2004 & (ptb_trough_mt!=. | ptb_peak_mt!=.)

*********************************************************************
**** Regression coefficients - deviantions from yearly averages
*********************************************************************
bysort cohort: regress ptb_dev haart_dev	
bysort cohort: regress ptb_dev haart_dev temp_dev
regress ptb_dev haart_dev
regress ptb_dev haart_dev temp_dev

bysort cohort: regress xptb_dev haart_dev
bysort cohort: regress xptb_dev haart_dev temp_dev
regress xptb_dev haart_dev
regress xptb_dev haart_dev temp_dev

bysort cohort: regress ks_dev haart_dev
bysort cohort: regress ks_dev haart_dev temp_dev
regress ks_dev haart_dev
regress ks_dev haart_dev temp_dev

*Adjusted for temeratures and/or latitudes
******************************************
gen latitude=0
replace latitude=-34.05 if cohort==1
replace latitude=-33.91 if cohort==2
replace latitude=-26.12 if cohort==3
replace latitude=-15.41 if cohort==4
replace latitude=-17.81 if cohort==5
				
regress ptb_dev haart_dev temp_dev
regress ptb_dev haart_dev temp_dev latitude
regress ptb_dev haart_dev temp_dev, cluster(latitude)

regress xptb_dev haart_dev temp_dev
regress xptb_dev haart_dev temp_dev latitude

regress ks_dev haart_dev temp_dev
regress ks_dev haart_dev temp_dev latitude

*********************************************************************
**** Graphs
*********************************************************************

*GRAPH AGGREGATED MONTHLY MEANS
*******************************
twoway (line haart_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lwidth(medthick)) (line ptb_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lwidth(medthick)) ///
	(line haart_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lpattern(shortdash) lwidth(medthick)) (line ptb_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lpattern(shortdash) lwidth(medthick)) ///
	if cohort==1, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(25 50 100 200 400, nogrid labsize(vsmall) angle(0)) ytitle("Number of events (log scale)", size(small)) ///
	legend(off) subtitle("South Africa - Khayelitsha", size(small)) yscale(log) ///
	saving("Khayelitsha", replace)

twoway (line haart_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lwidth(medthick)) (line ptb_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lwidth(medthick)) ///
	(line haart_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lpattern(shortdash) lwidth(medthick)) (line ptb_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lpattern(shortdash) lwidth(medthick)) ///
	if cohort==2, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(25 50 100 200 400, nogrid labsize(vsmall) angle(0)) ytitle(, size(small)) ///
	legend(off) subtitle("South Africa - Themba Lethu", size(small)) yscale(log) ///
	saving("ThembaLethu", replace)

twoway (line haart_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lwidth(medthick)) (line ptb_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lwidth(medthick)) ///
	(line haart_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lpattern(shortdash) lwidth(medthick)) (line ptb_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lpattern(shortdash) lwidth(medthick)) ///
	if cohort==3, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(2 5 10 25 50 100, nogrid labsize(vsmall) angle(0)) ytitle(, size(vsmall)) ///
	legend(off) subtitle("South Africa - Tygerberg", size(small)) yscale(log) ///
	saving("Tygerberg", replace)

twoway (line haart_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lwidth(medthick)) (line ptb_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lwidth(medthick)) ///
	(line haart_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lpattern(shortdash) lwidth(medthick)) (line ptb_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lpattern(shortdash) lwidth(medthick)) ///
	if cohort==4, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("Month", size(small)) ylabel(100 250 500 1000 2000 4000, nogrid labsize(vsmall) angle(0)) ytitle("Number of events (log scale)", size(small)) ///
	legend(off) subtitle("Zambia - CIDRZ", size(small)) yscale(log) ///
	saving("CIDRZ", replace)

twoway (line haart_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lwidth(medthick)) (line ptb_nb_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lwidth(medthick)) ///
	(line haart_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lpattern(shortdash) lwidth(medthick)) (line ptb_mt_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lpattern(shortdash) lwidth(medthick)) ///
	if cohort==5, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("Month", size(small)) ylabel(2 5 10 25 50 100, nogrid labsize(vsmall) angle(0)) ytitle(, size(small)) ///
	subtitle("Zimbabwe - Newlands", size(small)) yscale(log) ///
	legend(label(1 "ART start, average count") label(2 "PTB diagnosis, average count") order(1 2) ///
	size(vsmall) region(margin(tiny) lcolor(white)) bmargin(tiny) col(1) symxsize(2) pos(3)) ///
	saving("Newlands", replace)

grc1leg Khayelitsha.gph ThembaLethu.gph Tygerberg.gph CIDRZ.gph Newlands.gph, row(2) legendfrom (Newlands.gph) position(4) ring(0) graphregion(color(white)) saving ("combined_aggregated_averages")


*MEAN MONTHLY DEVIATIONS FROM YEARLY AVERAGE
********************************************
twoway (line haart_dev_mean midmonth, sort(midmonth) connect(direct) lcolor(gs10) lwidth(medthick)) (line ptb_dev_mean midmonth, sort(midmonth) connect(direct) lcolor(gs4) lwidth(medthick)), ///
	by(cohort, plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ix) ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", valuelabel labsize(vsmall)) xtitle("Months", size(vsmall)) ylabel(, labsize(vsmall) angle(0) nogrid) ytitle("Mean deviation from the average", size(vsmall)) ///
	legend(label(1 "ART starts") label(2 "PTB diagnosis") ///
	size(tiny) region(margin(tiny) lcolor(white)) bmargin(tiny) col(1) symxsize(2)) ///
	subtitle(, box bfcolor(white) blcolor(white) size(small)) 

*GRAPH 2004-2014 BY QUARTERS
****************************
use "datasets\collapsed_dataset_allquarters.dta", clear

twoway (line haart_nb quarter_y, lcolor(gs10) lwidth(medthick)) (line ptb_nb quarter_y, lcolor(gs4) lwidth(medthick)) , ///
	by(cohort, yrescale plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) ///
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("", size(vsmall)) ix) ///
	tlabel(2004q1(4)2014q1, labsize(vsmall) angle(45)) xtitle("Quarters", size(vsmall)) ///
	tlabel(2004q1 "2004" 2005q1 "2005" 2006q1 "2006" 2007q1 "2007" 2008q1 "2008" 2009q1 "2009" 2010q1 "2010" 2011q1 "2011" 2012q1 "2012" 2013q1 "2013" 2014q1 "2014") ///
	tmtick(2004q1(1)2014q4) ///
	ylabel(#5, labsize(vsmall) angle(0) nogrid) ytitle("Number of events", size(vsmall)) ///
	legend(label(1 "ART start, count") label(2 "PTB diagnosis, count") size(tiny) region(margin(tiny) lcolor(white)) bmargin(tiny) col(1) symxsize(2)) ///
	subtitle(, box bfcolor(white) blcolor(white) size(small))

*AGGREGATED AVERAGES BY SEX
use "datasets\collapsed_dataset_allmonths_final_bysex.dta", clear

twoway (line haart_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==1, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(25 50 100 200 400, nogrid labsize(vsmall) angle(0)) ytitle("Number of events (log scale)", size(small)) ///
	legend(off) subtitle("South Africa - Khayelitsha", size(small)) yscale(log) ///
	saving("Khayelitsha", replace)

twoway (line haart_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==2, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(25 50 100 200, nogrid labsize(vsmall) angle(0)) ytitle(, size(small)) ///
	legend(off) subtitle("South Africa - Themba Lethu", size(small)) yscale(log) ///
	saving("ThembaLethu", replace)

twoway (line haart_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==3, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(2 5 10 25 50, nogrid labsize(vsmall) angle(0)) ytitle(, size(vsmall)) ///
	legend(off) subtitle("South Africa - Tygerberg", size(small)) yscale(log) ///
	saving("Tygerberg", replace)

twoway (line haart_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==4, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("Month", size(small)) ylabel(100 250 500 1000 2000, nogrid labsize(vsmall) angle(0)) ytitle("Number of events (log scale)", size(small)) ///
	legend(off) subtitle("Zambia - CIDRZ", size(small)) yscale(log) ///
	saving("CIDRZ", replace)

twoway (line haart_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if gender==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if gender==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==5, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("Month", size(small)) ylabel(2 5 10 25 50, nogrid labsize(vsmall) angle(0)) ytitle(, size(small)) ///
	subtitle("Zimbabwe - Newlands", size(small)) yscale(log) ///
	legend(label(1 "ART start, average count - male") label(2 "PTB diagnosis, average count - male") label(3 "ART start, overall monthly mean - male") label(4 "PTB diagnosis, overall monthly mean - male") ///
	label(5 "ART start, average count - female") label(6 "PTB diagnosis, average count - female") label(7 "ART start, overall monthly mean - female") label(8 "PTB diagnosis, overall monthly mean - female") ///
	size(tiny) region(margin(tiny) lcolor(white)) bmargin(tiny) col(1) symxsize(2)) ///
	saving("Newlands", replace)

grc1leg Khayelitsha.gph ThembaLethu.gph Tygerberg.gph CIDRZ.gph Newlands.gph, row(2) legendfrom (Newlands.gph) position(4) ring(0) graphregion(color(white))

*AGGREGATED AVERAGES BY AGE
use "datasets\collapsed_dataset_allmonths_final_byage.dta", clear

twoway (line haart_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==1, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(25 50 100 200 400, nogrid labsize(vsmall) angle(0)) ytitle("Number of events (log scale)", size(small)) ///
	legend(off) subtitle("South Africa - Khayelitsha", size(small)) yscale(log) ///
	saving("Khayelitsha", replace)

twoway (line haart_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==2, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(25 50 100 200, nogrid labsize(vsmall) angle(0)) ytitle(, size(small)) ///
	legend(off) subtitle("South Africa - Themba Lethu", size(small)) yscale(log) ///
	saving("ThembaLethu", replace)

twoway (line haart_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==3, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("", size(small)) ylabel(2 5 10 25 50, nogrid labsize(vsmall) angle(0)) ytitle(, size(vsmall)) ///
	legend(off) subtitle("South Africa - Tygerberg", size(small)) yscale(log) ///
	saving("Tygerberg", replace)

twoway (line haart_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==4, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("Month", size(small)) ylabel(100 250 500 1000 2000, nogrid labsize(vsmall) angle(0)) ytitle("Number of events (log scale)", size(small)) ///
	legend(off) subtitle("Zambia - CIDRZ", size(small)) yscale(log) ///
	saving("CIDRZ", replace)

twoway (line haart_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick)) (line ptb_nb_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick)) ///
	(line haart_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin)) (line ptb_mt_mean midmonth if age_g==1, sort(midmonth) connect(direct) lcolor(black) lwidth(thin)) ///
	(line haart_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(medthick) lpattern(shortdash)) (line ptb_nb_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(medthick) lpattern(shortdash)) ///
	(line haart_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(gs8) lwidth(thin) lpattern(shortdash)) (line ptb_mt_mean midmonth if age_g==2, sort(midmonth) connect(direct) lcolor(black) lwidth(thin) lpattern(shortdash)) ///
	if cohort==5, ///	
	plotregion(fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white)) note("") ///
	xlabel(1"J" 2"F" 3"M" 4"A" 5"M" 6"J" 7"J" 8"A" 9"S" 10"O" 11"N" 12"D", labsize(vsmall)) xtitle("Month", size(small)) ylabel(2 5 10 25 50, nogrid labsize(vsmall) angle(0)) ytitle(, size(small)) ///
	subtitle("Zimbabwe - Newlands", size(small)) yscale(log) ///
	legend(label(1 "ART start, average count - <35 years") label(2 "PTB diagnosis, average count - <35 years") label(3 "ART start, overall monthly mean - <35 years") label(4 "PTB diagnosis, overall monthly mean - <35 years") ///
	label(5 "ART start, average count - >=35 years") label(6 "PTB diagnosis, average count - >=35 years") label(7 "ART start, overall monthly mean - >=35 years") label(8 "PTB diagnosis, overall monthly mean - >=35 years") ///
	size(tiny) region(margin(tiny) lcolor(white)) bmargin(tiny) col(1) symxsize(2)) ///
	saving("Newlands", replace)

grc1leg Khayelitsha.gph ThembaLethu.gph Tygerberg.gph CIDRZ.gph Newlands.gph, row(2) legendfrom (Newlands.gph) position(4) ring(0) graphregion(color(white))

log close
